@@ -1,6 +1,6 @@
 #ifndef lint
 static const char rcsid[] __attribute__ ((unused)) =
-    "@(#) $Id: cupdate.c 53 2023-04-02 22:45:45Z leres $ (LBL)";
+    "@(#) $Id: cupdate.c 55 2023-05-20 17:17:09Z leres $ (LBL)";
 #endif
 /*
  * Copyright (c) 2005, 2006, 2008, 2009, 2010, 2013, 2016, 2018, 2020, 2021, 2022, 2023
@@ -80,7 +80,7 @@ main(int argc, char **argv)
 	long lv;
 	char *cp, *ep, *cmd, *out, ch;
 	fd_set rfds;
-	struct timeval tv;
+	struct timeval now, tv, waittv;
 	const char *tty;
 	struct stat sbuf;
 
@@ -144,7 +144,6 @@ main(int argc, char **argv)
 	clear();
 	/* Turn off cursor */
 	curs_set(0);
-	tv.tv_usec = 0;
 	for (;;) {
 		out = runcommand(cmd);
 		erase();
@@ -152,10 +151,17 @@ main(int argc, char **argv)
 		refresh();
 		FD_ZERO(&rfds);
 		FD_SET(fileno(stdin), &rfds);
+
+		/* Try to run on the exact second */
+		(void)gettimeofday(&now, NULL);
+		now.tv_sec = 0;
 		tv.tv_sec = waitsecs;
+		tv.tv_usec = 0;
+		timersub(&tv, &now, &waittv);
+
 		/* Ignore slight race condition */
 		++waiting;
-		n = select(fileno(stdin) + 1, &rfds, NULL, NULL, &tv);
+		n = select(fileno(stdin) + 1, &rfds, NULL, NULL, &waittv);
 		waiting = 0;
 
 		/* ^C exit */
